RIL and network configuration update for new modem

- Updating RIL versions to match with new BP release.
- IP address update in iptables rules. It's for Motorola's debug
  interface only exposed in BP-tools mode.
- Added APNs which will be excluded from counting data usage.
  Requested from carrier.

Bug: 8140408
Change-Id: I62ede824139ab5b36239a5d8971332d8ebf260ef
diff --git a/board-info.txt b/board-info.txt
index d69c0e0..9e8367e 100644
--- a/board-info.txt
+++ b/board-info.txt
@@ -1,4 +1,4 @@
 require product=stingray|xoom-cdma|xoom-cdma-lte
 require version-bootloader=1050
-require version-baseband=CDMA_N_03.1A.64PS
-require-for-product:xoom-cdma-lte version-baseband-2=LTEDC_U_07.1F.00
+require version-baseband=CDMA_N_03.1A.70PS
+require-for-product:xoom-cdma-lte version-baseband-2=LTEDC_U_09.1F.00
diff --git a/overlay/frameworks/base/core/res/res/values/config.xml b/overlay/frameworks/base/core/res/res/values/config.xml
index 561ffc7..8d2b94c 100644
--- a/overlay/frameworks/base/core/res/res/values/config.xml
+++ b/overlay/frameworks/base/core/res/res/values/config.xml
@@ -30,4 +30,13 @@
         <item>/dev/bus/usb/002</item>
     </string-array>
 
+    <!-- exclude the none-billable APNs for data usage calculation -->
+    <integer-array translatable="false" name="config_data_usage_network_types">
+        <item>0</item> <!-- TYPE_MOBILE -->
+        <item>2</item> <!-- TYPE_MOBILE_MMS -->
+        <item>3</item> <!-- TYPE_MOBILE_SUPL -->
+        <item>4</item> <!-- TYPE_MOBILE_DUN -->
+        <item>5</item> <!-- TYPE_MOBILE_HIPRI -->
+    </integer-array>
+
 </resources>
diff --git a/ril/libmoto_lte_ril.so b/ril/libmoto_lte_ril.so
index 911ed87..8537fa1 100644
--- a/ril/libmoto_lte_ril.so
+++ b/ril/libmoto_lte_ril.so
Binary files differ
diff --git a/ril/libmoto_mm_ril.so b/ril/libmoto_mm_ril.so
index b7ffeb9..ceb70a4 100644
--- a/ril/libmoto_mm_ril.so
+++ b/ril/libmoto_mm_ril.so
Binary files differ
diff --git a/ril/wrigley-dump.sh b/ril/wrigley-dump.sh
index 195479d..130295b 100755
--- a/ril/wrigley-dump.sh
+++ b/ril/wrigley-dump.sh
@@ -35,7 +35,7 @@
 # and writes.  Use a value that is not likely to false-positive, but also
 # provides adequate protection against hanging for a long time.
 for cmd in "state" "files" "atvc"; do
-    echo "-o wrigley $cmd" | nc -w 10 192.168.20.2 3002
+    echo "-o wrigley $cmd" | nc -w 10 192.168.157.2 3002
 done
 echo "file:begin:txt:wrigley/AdditionalExtractionInstructions.txt"
 echo "To extract logs.gz and panic.gz, you must do the following:"
@@ -52,6 +52,6 @@
 echo "file:end:txt:wrigley/AdditionalExtractionInstructions.txt"
 for cmd in "logs" "panic"; do
     echo "file:begin:bin:wrigley/${cmd}.gz"
-    echo "$cmd" | nc -w 10 192.168.20.2 3002 | gzip | base64 -e
+    echo "$cmd" | nc -w 10 192.168.157.2 3002 | gzip | base64 -e
     echo "file:end:bin:wrigley/${cmd}.gz"
 done
diff --git a/ril/wrigley-fetch-mpr.sh b/ril/wrigley-fetch-mpr.sh
index cd9d793..4435cec 100755
--- a/ril/wrigley-fetch-mpr.sh
+++ b/ril/wrigley-fetch-mpr.sh
@@ -5,5 +5,5 @@
     "") echo "Usage: $0 <destination dir>"; exit 1;;
 esac
 for cmd in "state" "-d logs" "files" "-d panic" "atvc"; do
-    echo "$cmd" | nc 192.168.20.2 3002 | extract-embedded-files -o "$mprTempDir"
+    echo "$cmd" | nc 192.168.157.2 3002 | extract-embedded-files -o "$mprTempDir"
 done
diff --git a/ril/wrigley-iptables.sh b/ril/wrigley-iptables.sh
index 9234407..f0b4c05 100755
--- a/ril/wrigley-iptables.sh
+++ b/ril/wrigley-iptables.sh
@@ -25,7 +25,7 @@
 # TODO: Implement a connection-based auth scheme for Wrigley control and
 # TODO: diagnostics ports.
 
 # NOTE: Our usage of the static 192.168.20.0/24 for the Wrigley IP address can
 # cause conflicts with DHCP-assigned WiFi addresses.  When coupled with the
 # firewall below, this ensures that WiFi will not work if we get assigned an
 # address in that range.
@@ -35,11 +35,11 @@
 IPTABLES="/system/bin/iptables"
 
 #### filter OUTPUT ####
 # Setup an explicit sub-chain for 192.168.20.2.  This way we only burden all
 # other packets with a single check for the IP address.
 $IPTABLES -F oem_out_wrigley # No-op on 1st inst of this script
 $IPTABLES -N oem_out_wrigley # No-op on 2nd-Nth inst of this script
-$IPTABLES -A oem_out -d 192.168.20.2 -j oem_out_wrigley
+$IPTABLES -A oem_out -d 192.168.157.2 -j oem_out_wrigley
 
 # Setup diff rules for sensitive ports vs other ports.  There are more
 # non-sensitive than sensitive ports, and the non-sensitive list is fairly
@@ -73,15 +73,15 @@
     # dynamic.  So, do a blacklist instead of a whitelist.
     $IPTABLES -F oem_fwd_wrigley # No-op on 1st inst of this script
     $IPTABLES -N oem_fwd_wrigley # No-op on 2nd-Nth inst of this script
-    $IPTABLES -A oem_fwd -d 192.168.20.2 -j oem_fwd_wrigley
-    $IPTABLES -A oem_fwd -s 192.168.20.2 -j oem_fwd_wrigley
+    $IPTABLES -A oem_fwd -d 192.168.157.2 -j oem_fwd_wrigley
+    $IPTABLES -A oem_fwd -s 192.168.157.2 -j oem_fwd_wrigley
     $IPTABLES -A oem_fwd_wrigley -p tcp --dport 3265 -j REJECT
     $IPTABLES -A oem_fwd_wrigley -p tcp --dport 3267 -j REJECT
     $IPTABLES -A oem_fwd_wrigley -p tcp --dport 11000 -j REJECT
     $IPTABLES -A oem_fwd_wrigley -j ACCEPT
     ;;
 *)
-    $IPTABLES -A oem_fwd -d 192.168.20.2 -j REJECT
+    $IPTABLES -A oem_fwd -d 192.168.157.2 -j REJECT
     ;;
 esac
 
@@ -90,6 +90,6 @@
 bp-tools)
     # We must rewrite the destination address for our SUAPI logger port to the
     # address of the BLAN, because legacy tools (RTA/PST) rely on this.
-    $IPTABLES -t nat -A oem_nat_pre -p tcp -d 192.168.16.2 --dport 11006 -j DNAT --to 192.168.20.2:11006
+    $IPTABLES -t nat -A oem_nat_pre -p tcp -d 192.168.16.2 --dport 11006 -j DNAT --to 192.168.157.2:11006
     ;;
 esac
@@ -25,7 +25,7 @@
 # TODO: diagnostics ports.
 
-# NOTE: Our usage of the static 192.168.20.0/24 for the Wrigley IP address can
+# NOTE: Our usage of the static 192.168.157.0/24 for the Wrigley IP address can
 # cause conflicts with DHCP-assigned WiFi addresses.  When coupled with the
 # firewall below, this ensures that WiFi will not work if we get assigned an
@@ -35,11 +35,11 @@
 
 #### filter OUTPUT ####
-# Setup an explicit sub-chain for 192.168.20.2.  This way we only burden all
+# Setup an explicit sub-chain for 192.168.157.2.  This way we only burden all
 # other packets with a single check for the IP address.
 $IPTABLES -F oem_out_wrigley # No-op on 1st inst of this script